"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = __importStar(require("chai"));
const chai_as_promised_1 = __importDefault(require("chai-as-promised"));
const mergeI18nMessagesWithLocaleFileContent_1 = require("./mergeI18nMessagesWithLocaleFileContent");
chai_1.default.use(chai_as_promised_1.default);
describe("mergeI18nMessagesWithLocaleFileContent", async () => {
    it("should not add addition properties", () => {
        const locale = `
    export const en: TranslationMessages = {
      ...englishMessages
    }`;
        const localeExpected = `
    export const en: TranslationMessages = {
      ...englishMessages
    }`;
        const localeResult = (0, mergeI18nMessagesWithLocaleFileContent_1.mergeI18nMessagesWithLocaleFileContent)(locale, "en", {});
        (0, chai_1.expect)(localeResult).to.deep.equal(localeExpected);
    });
    it("should ignore not identifier keys", () => {
        const locale = `
    export const en: TranslationMessages = {
      ...englishMessages,
      [not.identifier.key]: "AnyValue",
      [10]: "AnyValue"
    }`;
        const localeExpected = `
    export const en: TranslationMessages = {
      ...englishMessages
    }`;
        const localeResult = (0, mergeI18nMessagesWithLocaleFileContent_1.mergeI18nMessagesWithLocaleFileContent)(locale, "en", {});
        (0, chai_1.expect)(localeResult).to.deep.equal(localeExpected);
    });
    it("should ignore not object, not string or not spreadElement values", () => {
        const locale = `
    export const en: TranslationMessages = {
      ...englishMessages,
      anyKeyOne: true,
      anyKeyTwo: 3,
      anyKeyTree: new Error(),
      anyKeyFour: [],
    }`;
        const localeExpected = `
    export const en: TranslationMessages = {
      ...englishMessages,
      anyKeyTree: {},
      anyKeyFour: {}
    }`;
        const localeResult = (0, mergeI18nMessagesWithLocaleFileContent_1.mergeI18nMessagesWithLocaleFileContent)(locale, "en", {});
        (0, chai_1.expect)(localeResult).to.deep.equal(localeExpected);
    });
    it("should add 'resources' object and messages to locale without resources", () => {
        const locale = `
    export const en: TranslationMessages = {
      ...englishMessages,
    }`;
        const localeExpected = `
    export const en: TranslationMessages = {
      ...englishMessages,

      resources: {
        AnyDTO: {
          newField: "newValue"
        }
      }
    }`;
        const localeResult = (0, mergeI18nMessagesWithLocaleFileContent_1.mergeI18nMessagesWithLocaleFileContent)(locale, "en", {
            resources: {
                AnyDTO: {
                    newField: "newValue",
                },
            },
        });
        (0, chai_1.expect)(localeResult).to.deep.equal(localeExpected);
    });
    it("should handle string keys with dots", () => {
        const locale = `
    export const en: TranslationMessages = {
      ...englishMessages,

      resources: {
        AnyDTO: {
          "oldField.id": "oldValue"
        }
      }
    }`;
        const localeExpected = `
    export const en: TranslationMessages = {
      ...englishMessages,

      resources: {
        AnyDTO: {
          "newField.id": "newValue",
          "oldField.id": "oldValue"
        }
      }
    }`;
        const localeResult = (0, mergeI18nMessagesWithLocaleFileContent_1.mergeI18nMessagesWithLocaleFileContent)(locale, "en", {
            resources: {
                AnyDTO: {
                    "newField.id": "newValue",
                },
            },
        });
        (0, chai_1.expect)(localeResult).to.deep.equal(localeExpected);
    });
    it("should add messages to locale with resources", () => {
        const locale = `
    export const en: TranslationMessages = {
      ...englishMessages,
      resources: {}
    }`;
        const localeExpected = `
    export const en: TranslationMessages = {
      ...englishMessages,

      resources: {
        AnyDTO: {
          newField: "newValue"
        }
      }
    }`;
        const localeResult = (0, mergeI18nMessagesWithLocaleFileContent_1.mergeI18nMessagesWithLocaleFileContent)(locale, "en", {
            resources: {
                AnyDTO: {
                    newField: "newValue",
                },
            },
        });
        (0, chai_1.expect)(localeResult).to.deep.equal(localeExpected);
    });
    it("should merge messages and leave old ones unmodified to locale with resources", () => {
        const locale = `
    export const en: TranslationMessages = {
      ...englishMessages,
      resources: {
        AnyDTO: {
          oldTouchedField: "oldValue",
          oldUntouchedField: "oldValue",
        }
      }
    }`;
        const localeExpected = `
    export const en: TranslationMessages = {
      ...englishMessages,

      resources: {
        AnyDTO: {
          newField: "newValue",
          oldTouchedField: "oldValue",
          oldUntouchedField: "oldValue"
        }
      }
    }`;
        const localeResult = (0, mergeI18nMessagesWithLocaleFileContent_1.mergeI18nMessagesWithLocaleFileContent)(locale, "en", {
            resources: {
                AnyDTO: {
                    newField: "newValue",
                    oldTouchedField: "newValue",
                },
            },
        });
        (0, chai_1.expect)(localeResult).to.deep.equal(localeExpected);
    });
    it("should throw error if variable with locale not found", async () => {
        const locale = `
    export const notMessages: TranslationMessages = {
      ...englishMessages,
    }`;
        (0, chai_1.should)().throw(() => (0, mergeI18nMessagesWithLocaleFileContent_1.mergeI18nMessagesWithLocaleFileContent)(locale, "messages", {}), "'messages' variable not found in i18n file");
    });
});
//# sourceMappingURL=mergeI18nMessagesWithLocaleFileContent.test.js.map